@@ -26,7 +26,7 @@ class ProblemSolution(StructuredNode):
 
 class Topic(StructuredNode):
     client_id = StringProperty(required=True, index=True)
-    text = StringProperty(required=True, unique_index = True)
+    text = StringProperty(required=True, index = True)
     tsne_coords = StringProperty(required=True)
     process_datetime = DateTimeProperty(default_now=True)
 
@@ -36,7 +36,7 @@ class TopicRel(StructuredRel):
 
 class SubTopic(StructuredNode):
     client_id = StringProperty(required=True, index=True)
-    text = StringProperty(required=True, unique_index = True)
+    text = StringProperty(required=True, index = True)
     topic = Relationship(Topic, 'HAS_TOPIC', model=TopicRel)
     process_datetime = DateTimeProperty(default_now=True)
 
@@ -46,18 +46,18 @@ class SubTopicRel(StructuredRel):
 
 class Sentiment(StructuredNode):
     client_id = StringProperty(required=True, index=True)
-    sentiment = IntegerProperty(required=True, unique_index=True)
+    sentiment = IntegerProperty(required=True, index=True)
     process_datetime = DateTimeProperty(default_now=True)
 
 
 class UserMood(StructuredNode):
     client_id = StringProperty(required=True, index=True)
-    mood = IntegerProperty(required=True, unique_index=True)
+    mood = IntegerProperty(required=True, index=True)
 
     
 class Emoji(StructuredNode):
     client_id = StringProperty(required=True, index=True)
-    label = StringProperty(required=True, unique_index=True)
+    label = StringProperty(required=True, index=True)
     pax_label = StringProperty(required=True)
     group = StringProperty(required=True)
     plutchik_category = StringProperty()
